@@ -6,7 +6,7 @@ use Carp qw( croak    );
 use Sys::Info::Constants qw( OSID );
 use base qw( Sys::Info::Base );
 
-$VERSION = '0.73';
+$VERSION = '0.78';
 @EXPORT_OK = qw( OSID );
 
 __PACKAGE__->_mk_object( $_ ) for qw( OS Device );
@@ -112,8 +112,8 @@ Sys::Info - Fetch information from the host system
 
 =head1 DESCRIPTION
 
-This document describes version C<0.73> of C<Sys::Info>
-released on C<14 January 2010>.
+This document describes version C<0.78> of C<Sys::Info>
+released on C<17 April 2011>.
 
 Extracts and collects information from the host system.
 
@@ -160,6 +160,7 @@ Returns the OS identifier.
 
 =head1 SEE ALSO
 
+L<Sys::Info::Base>,
 L<Sys::Info::OS>,
 L<Sys::Info::Device>,
 L<Filesys::Ext2>,
@@ -193,12 +194,12 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2006 - 2011 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.1 or, 
+it under the same terms as Perl itself, either Perl version 5.12.3 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
